@@ -151,10 +151,6 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-#if !GLIB_CHECK_VERSION( 2,36, 0 )
-	g_type_init();
-#endif
-
 	type = g_type_register_static( G_TYPE_OBJECT, "BaseApplication", &info, 0 );
 
 	g_type_add_interface_static( type, BASE_TYPE_ISESSION, &isession_iface_info );
