@@ -31,8 +31,8 @@
 #include <config.h>
 #endif
 
+#include <glib.h>
 #include <glib/gi18n.h>
-#include <libintl.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -698,7 +698,7 @@ on_desktop_toggled( GtkCellRendererToggle *renderer, gchar *path, BaseWindow *wi
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	GtkTreePath *tree_path;
-	gboolean state;
+	gboolean state = FALSE;
 	gchar *desktop;
 	GtkWidget *show_button;
 	IEnvironData *data;
