@@ -34,22 +34,23 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
 
 #include <gio/gio.h>
 #include <glib/gstdio.h>
+#include <gtk/gtk.h>
 
 #include <api/na-core-utils.h>
 
-#include "na-about.h"
-
 /* minimal and maximal size for loading the content of a file in memory
  * used by na_core_utils_file_is_size_ok()
  */
-#define SIZE_MIN		  1
-#define SIZE_MAX	1048576		/* 1 MB */
+#define CA_SIZE_MIN           1
+#define CA_SIZE_MAX     1048576 /* 1 MB */
 
 #ifdef NA_ENABLE_DEPRECATED
 static GSList  *text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value );
@@ -1089,7 +1090,7 @@ file_is_loadable( GFile *file )
 	} else {
 		size = g_file_info_get_attribute_uint64( info, G_FILE_ATTRIBUTE_STANDARD_SIZE );
 		g_debug( "%s: size=%lu", thisfn, ( unsigned long ) size );
-		isok = ( size >= SIZE_MIN && size <= SIZE_MAX );
+		isok = ( size >= CA_SIZE_MIN && size <= CA_SIZE_MAX );
 	}
 
 	if( isok ){
@@ -1224,13 +1225,12 @@ na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
 void
 na_core_utils_print_version( void )
 {
-	gchar *copyright;
 
 	g_print( "\n" );
 	g_print( "%s (%s) v %s\n", g_get_prgname(), PACKAGE_NAME, PACKAGE_VERSION );
-	copyright = na_about_get_copyright( TRUE );
-	g_print( "%s\n", copyright );
-	g_free( copyright );
+	g_print ("%s\n", _("Copyright (C) 2009-2012 Pierre Wieser <pwieser@trychlos.org>\n"
+	                   "Copyright (C) 2013-2020 Wolfgang Ulbrich <mate@raveit.de>\n"
+	                   "Copyright (C) 2021 The MATE developers"));
 
 	g_print( "%s is free software, and is provided without any warranty. You may\n", PACKAGE_NAME );
 	g_print( "redistribute copies of %s under the terms of the GNU General Public\n", PACKAGE_NAME );
