@@ -341,10 +341,6 @@ main( int argc, char **argv )
 {
 	TestBase *base;
 
-#if !GLIB_CHECK_VERSION( 2,36, 0 )
-	g_type_init();
-#endif
-
 	g_debug( "allocating TestBase -------------------------------------" );
 	base = test_base_new();
 
