@@ -101,10 +101,6 @@ main( int argc, char** argv )
 	NAType type;
 	gchar *msgerr;
 
-#if !GLIB_CHECK_VERSION( 2,36, 0 )
-	g_type_init();
-#endif
-
 	setlocale( LC_ALL, "" );
 	console_init_log_handler();
 
